Learn R Programming

pom (version 1.1)

print.mixed.pom: Printing Patch Occupancy Model Fits For a Beta-binomial Mixture

Description

This function summarizes the results from class mixed.pom. This function is called when a "~Beta.mixture" is specified as the model for p (probability of detection).

Usage

"print"( x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
an object of class mixed.pom; usually, a result of a call to siteocc.
digits
the number of significant digits to use when printing.
...
further arguments passed to or from other methods. They are ignored in this function.

Value

The output includes the matched call, the convergence code, PSI Coefficients with Estimates, Standard Errors, Z-values, and 2-sided p-values, Beta mixture parameters for P, AIC, BIC, the average estimated Probability of Occupancy (PSI).

See Also

weta.data siteocc

Examples

Run this code
data(weta.data) 
	
fit1 <- siteocc(~1, ~1, histories=weta.data$detection.histories) 
print(fit1)

Run the code above in your browser using DataLab